@@ -9,7 +9,7 @@ if 'alphafed' in logging.Logger.manager.loggerDict.keys():
 
 else:
     format = '%(asctime)s|%(levelname)s|%(module)s|%(funcName)s|%(lineno)d:\n%(message)s'
-    logging.basicConfig(level=logging.DEBUG,
+    logging.basicConfig(level=logging.INFO,
                         filename='alphafed.log',
                         filemode='w',
                         format=format)
@@ -19,6 +19,3 @@ else:
     logger.addHandler(console_handler)
 
 task_logger = logging.getLogger('task')
-
-
-DEV_TASK_ID = 'ceb1ddac12e54fdab888194a01137e8b'
