@@ -113,8 +113,7 @@ class DPFedAvgScheduler(FedAvgScheduler, metaclass=ABCMeta):
     def _setup_context(self, id: str, task_id: str, is_initiator: bool = False):
         super()._setup_context(id, task_id, is_initiator)
         if self.involve_aggregator:
-            loader = self.make_train_dataloader()
-            self._w_ks[self.id] = self._calc_w_k(len(loader.dataset))
+            self._w_ks[self.id] = self._calc_w_k(len(self.train_loader.dataset))
         self.contractor = DPFedAvgContractor(task_id=self.task_id)
 
     def _calc_w_k(self, n_k: int) -> float:
@@ -153,21 +152,19 @@ class DPFedAvgScheduler(FedAvgScheduler, metaclass=ABCMeta):
 
     def _check_in_task(self) -> bool:
         """Try to check in the task."""
-        train_loader = self.make_train_dataloader()
-        nonce = self.contractor.checkin(peer_id=self.id, n_k=len(train_loader.dataset))
+        nonce = self.contractor.checkin(peer_id=self.id, n_k=len(self.train_loader.dataset))
         return self._wait_for_checkin_response(nonce=nonce, timeout=self.schedule_timeout)
 
     def _execute_training(self):
         self.model.train()
         self._theta_0 = deepcopy(tuple(self.model.parameters()))
         for _ in range(self.merge_epochs):
-            train_loader = self.make_train_dataloader()
-            for batch_data in train_loader:
+            for batch_data in self.train_loader:
                 self.train_a_batch(*batch_data)
                 self._per_layer_clip()
 
     @final
-    def train(self):
+    def train_an_epoch(self):
         raise NotImplementedError()
 
     @torch.no_grad()
@@ -202,32 +199,32 @@ class DPFedAvgScheduler(FedAvgScheduler, metaclass=ABCMeta):
 
         with torch.no_grad():
             state_dict_0 = self.model.state_dict()
-            _model = self.make_model()
-            _model.load_state_dict(state_dict_0)
-            self._theta_0 = deepcopy(tuple(_model.parameters()))
+            _trans_model = self.build_model()
+            _trans_model.load_state_dict(state_dict_0)
+            self._theta_0 = deepcopy(tuple(_trans_model.parameters()))
 
             accum_delta = tuple(torch.zeros(_param.size()) for _param in self._theta_0)
             for _peer_id, _state_dict in state_dicts.items():
                 if _peer_id not in self._w_ks:
                     raise AggregationError(f'The w_s value of ID: {_peer_id} is lost.')
-                _model.load_state_dict(_state_dict)
+                _trans_model.load_state_dict(_state_dict)
                 w_k = self._w_ks[_peer_id]
-                for _param, _param_0 in zip(_model.parameters(), self._theta_0):
+                for _param, _param_0 in zip(_trans_model.parameters(), self._theta_0):
                     if not _param.requires_grad:
                         continue
                     _param.sub_(_param_0)
-                for _delta_param, _accum_delta_param in zip(_model.parameters(), accum_delta):
+                for _delta_param, _accum_delta_param in zip(_trans_model.parameters(), accum_delta):
                     _accum_delta_param.add_(_delta_param * w_k / self.q / self.W)
 
             sigme = self.z * self.S / self.q / self.W
-            _model.load_state_dict(state_dict_0)
-            for _param, _delta in zip(_model.parameters(), accum_delta):
+            _trans_model.load_state_dict(state_dict_0)
+            for _param, _delta in zip(_trans_model.parameters(), accum_delta):
                 if not _param.requires_grad:
                     continue
                 _param.add_(_delta)
                 _param.add_(torch.normal(mean=0.0, std=sigme ** 2, size=_param.size()))
 
-            new_state_dict = _model.state_dict()
+            new_state_dict = _trans_model.state_dict()
             self.model.load_state_dict(new_state_dict)
             self.push_log('Obtained a new version of parameters.')
 
